@@ -1,60 +1,14 @@
 package Business::ID::SIM;
+our $VERSION = '0.02';
+# ABSTRACT: Validate Indonesian driving license number (nomor SIM)
+
 
 use warnings;
 use strict;
 use DateTime;
 require Exporter;
-use vars qw(@ISA @EXPORT);
-@ISA = qw(Exporter);
-@EXPORT = qw(validate_sim);
-
-=head1 NAME
-
-Business::ID::SIM - Validate Indonesian driving license number (nomor SIM)
-
-=head1 VERSION
-
-Version 0.01
-
-=cut
-
-our $VERSION = '0.01';
-
-=head1 SYNOPSIS
-
-    use Business::ID::SIM;
-    
-    # OO-style
-
-    my $sim = Business::ID::SIM->new($str);
-    die "Invalid SIM!" unless $sim->validate;
-
-    print $sim->year_of_birth, "\n"; # also, yob()
-    print $sim->mon_of_birth, "\n"; # also, mob()
-    print $sim->area_code, "\n";
-    print $sim->serial, "\n";
-
-    # procedural style
-
-    validate_sim($str) or die "Invalid SIM!";
-    
-=head1 DESCRIPTION
-
-This module can be used to validate Indonesian driving license number,
-Nomor Surat Izin Mengemudi (SIM).
-
-SIM is composed of 12 digits as follow:
-
- yymm.pp.aa.ssss
-
-yy and mm are year and month of birth, pp and aa are area code
-(province+district of some sort), ssss is 4-digit serial most probably
-starting from 1.
-
-Note that there are several kinds of SIM (A, B1, B2, C) but this is
-not encoded in the SIM number and all SIM's have the same number.
-
-=cut
+our @ISA = qw(Exporter);
+our @EXPORT = qw(validate_sim);
 
 # legend: S = lack of samples
 
@@ -85,13 +39,6 @@ my %provinces = (
 
     );
 
-=head1 METHODS
-
-=head2 new $str
-
-Create a new C<Business::ID::SIM> object.
-
-=cut
 
 sub new {
     my ($class, $str) = @_;
@@ -103,13 +50,6 @@ sub new {
     }, $class;
 }
 
-=head2 validate()
-
-Return true if SIM is valid, or false if otherwise. In the case of SIM
-being invalid, you can call the errstr() method to get a description
-of the error.
-
-=cut
 
 sub validate {
     my ($self, $another) = @_;
@@ -145,12 +85,6 @@ sub validate {
     $self->{_res} = 1;
 }
 
-=head2 errstr()
-
-Return validation error of SIM, or undef if no error is found. See
-C<validate()>.
-
-=cut
 
 sub errstr {
     my ($self) = @_;
@@ -158,11 +92,6 @@ sub errstr {
     $self->{_err};
 }
 
-=head2 normalize()
-
-Return formatted SIM, or undef if SIM is invalid.
-
-=cut
 
 sub normalize {
     my ($self, $another) = @_;
@@ -171,19 +100,9 @@ sub normalize {
     $self->{_str};
 }
 
-=head2 pretty()
-
-Alias for normalize().
-
-=cut
 
 sub pretty { normalize(@_) }
 
-=head2 area_code()
-
-Return 4-digit 'province'+district code component of SIM.
-
-=cut
 
 sub area_code {
     my ($self) = @_;
@@ -192,12 +111,6 @@ sub area_code {
     $1;
 }
 
-=head2 year_of_birth()
-
-Return year component of the SIM, already added with the century, or
-undef if SIM is invalid.
-
-=cut
 
 sub year_of_birth {
     my ($self) = @_;
@@ -205,19 +118,9 @@ sub year_of_birth {
     $self->{_dob}->year;
 }
 
-=head2 yob()
-
-Alias for year_of_birth()
-
-=cut
 
 sub yob { year_of_birth(@_) }
 
-=head2 month_of_birth()
-
-Return month component of the SIM, or undef if SIM is invalid.
-
-=cut
 
 sub month_of_birth {
     my ($self) = @_;
@@ -225,19 +128,9 @@ sub month_of_birth {
     $self->{_dob}->mon;
 }
 
-=head2 mob()
-
-Alias for month_of_birth().
-
-=cut
 
 sub mob { month_of_birth(@_) }
 
-=head2 serial()
-
-Return 4-digit serial component of SIM, or undef if SIM is invalid.
-
-=cut
 
 sub serial {
     my ($self) = @_;
@@ -246,6 +139,110 @@ sub serial {
     $1;
 }
 
+
+sub validate_sim {
+    my ($str) = @_;
+    Business::ID::SIM->new($str)->validate();
+}
+
+
+1;
+
+__END__
+=pod
+
+=head1 NAME
+
+Business::ID::SIM - Validate Indonesian driving license number (nomor SIM)
+
+=head1 VERSION
+
+version 0.02
+
+=head1 SYNOPSIS
+
+    use Business::ID::SIM;
+    
+    # OO-style
+
+    my $sim = Business::ID::SIM->new($str);
+    die "Invalid SIM!" unless $sim->validate;
+
+    print $sim->year_of_birth, "\n"; # also, yob()
+    print $sim->mon_of_birth, "\n"; # also, mob()
+    print $sim->area_code, "\n";
+    print $sim->serial, "\n";
+
+    # procedural style
+
+    validate_sim($str) or die "Invalid SIM!";
+
+=head1 DESCRIPTION
+
+This module can be used to validate Indonesian driving license number,
+Nomor Surat Izin Mengemudi (SIM).
+
+SIM is composed of 12 digits as follow:
+
+ yymm.pp.aa.ssss
+
+yy and mm are year and month of birth, pp and aa are area code
+(province+district of some sort), ssss is 4-digit serial most probably
+starting from 1.
+
+Note that there are several kinds of SIM (A, B1, B2, C) but this is
+not encoded in the SIM number and all SIM's have the same number.
+
+=head1 METHODS
+
+=head2 new $str
+
+Create a new C<Business::ID::SIM> object.
+
+=head2 validate()
+
+Return true if SIM is valid, or false if otherwise. In the case of SIM
+being invalid, you can call the errstr() method to get a description
+of the error.
+
+=head2 errstr()
+
+Return validation error of SIM, or undef if no error is found. See
+C<validate()>.
+
+=head2 normalize()
+
+Return formatted SIM, or undef if SIM is invalid.
+
+=head2 pretty()
+
+Alias for normalize().
+
+=head2 area_code()
+
+Return 4-digit 'province'+district code component of SIM.
+
+=head2 year_of_birth()
+
+Return year component of the SIM, already added with the century, or
+undef if SIM is invalid.
+
+=head2 yob()
+
+Alias for year_of_birth()
+
+=head2 month_of_birth()
+
+Return month component of the SIM, or undef if SIM is invalid.
+
+=head2 mob()
+
+Alias for month_of_birth().
+
+=head2 serial()
+
+Return 4-digit serial component of SIM, or undef if SIM is invalid.
+
 =head1 FUNCTIONS
 
 =head2 validate_sim($string)
@@ -256,33 +253,25 @@ C<errstr> method).
 
 Exported by default.
 
-=cut
-
-sub validate_sim {
-    my ($str) = @_;
-    Business::ID::SIM->new($str)->validate();
-}
-
 =head1 AUTHOR
 
 Steven Haryanto, C<< <stevenharyanto at gmail.com> >>
 
 =head1 BUGS
 
+The list of valid 'province' codes in the program might need to be
+updated from time to time.
+
 Please report any bugs or feature requests to C<bug-business-id-sim at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Business-ID-SIM>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Business::ID::SIM
 
-
 You can also look for information at:
 
 =over 4
@@ -305,10 +294,8 @@ L<http://search.cpan.org/dist/Business-ID-SIM/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009 Steven Haryanto.
@@ -319,7 +306,16 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
+=head1 AUTHOR
+
+  Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Steven Haryanto.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
